@@ -24,6 +24,8 @@ from .postgres_fields import (
     FloatRangeModelFieldTransformer,
 )
 from .shortcuts import RenderToResponseTransformer
+from .signals import SignalDisconnectWeakTransformer
+from .template_tags import AssignmentTagTransformer
 from .timezone import FixedOffsetTransformer
 from .translations import (
     UGetTextLazyTransformer,
@@ -36,6 +38,7 @@ from .urls import URLTransformer
 
 __all__ = (
     "AbsPathTransformer",
+    "AssignmentTagTransformer",
     "AvailableAttrsTransformer",
     "ContextDecoratorTransformer",
     "FixedOffsetTransformer",
@@ -54,6 +57,7 @@ __all__ = (
     "OnDeleteTransformer",
     "QuerySetPaginatorTransformer",
     "RenderToResponseTransformer",
+    "SignalDisconnectWeakTransformer",
     "SmartTextTransformer",
     "UGetTextLazyTransformer",
     "UGetTextNoopTransformer",
