@@ -23,18 +23,18 @@ class BaseDjCodemodTransformer(ContextAwareTransformer, ABC):
     removed_in: Tuple[int, int]
 
 
-def module_matcher(import_parts):
+def module_matcher(import_parts: Sequence) -> Union[m.BaseMatcherNode, m.DoNotCare]:
+    """Build matcher for a module given sequence of import parts."""
+    # If only one element, it is just a Name
+    if len(import_parts) == 1:
+        return m.Name(import_parts[0])
     *values, attr = import_parts
-    if len(values) > 1:
-        value = module_matcher(values)
-    elif len(values) == 1:
-        value = m.Name(values[0])
-    else:
-        value = m.DoNotCare()
+    value = module_matcher(values)
     return m.Attribute(value=value, attr=m.Name(attr))
 
 
-def import_from_matches(node, module_parts):
+def import_from_matches(node: ImportFrom, module_parts: Sequence):
+    """Check if an `ImportFrom` node matches sequence of module parts."""
     return m.matches(node, m.ImportFrom(module=module_matcher(module_parts)))
 
 
