@@ -1,9 +1,9 @@
 from django_codemod.constants import DJANGO_2_0, DJANGO_3_0
-from django_codemod.visitors.base import BaseSimpleFuncRenameTransformer
+from django_codemod.visitors.base import BaseFuncRenameTransformer
 
 
-class LRUCacheTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.lru_cache.lru_cache``."""
+class LRUCacheTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.lru_cache.lru_cache` by `functools.lru_cache`."""
 
     deprecated_in = DJANGO_2_0
     removed_in = DJANGO_3_0
