@@ -16,15 +16,14 @@ from libcst import (
     Return,
 )
 from libcst import matchers as m
-from libcst.codemod import ContextAwareTransformer
 from libcst.codemod.visitors import AddImportsVisitor
 
 from django_codemod.constants import DJANGO_1_9, DJANGO_1_11, DJANGO_2_0, DJANGO_2_1
-from django_codemod.visitors.base import module_matcher
+from django_codemod.visitors.base import BaseDjCodemodTransformer, module_matcher
 
 
-class ModelsPermalinkTransformer(ContextAwareTransformer):
-    """Replaces ``@models.permalink`` decorator by a call to ``reverse()``."""
+class ModelsPermalinkTransformer(BaseDjCodemodTransformer):
+    """Replace `@models.permalink` decorator by a call to `reverse()`."""
 
     deprecated_in = DJANGO_1_11
     removed_in = DJANGO_2_1
@@ -36,7 +35,8 @@ class ModelsPermalinkTransformer(ContextAwareTransformer):
         self, original_node: ImportFrom, updated_node: ImportFrom
     ) -> Union[BaseSmallStatement, RemovalSentinel]:
         if m.matches(
-            updated_node, m.ImportFrom(module=module_matcher(["django", "db"])),
+            updated_node,
+            m.ImportFrom(module=module_matcher(["django", "db"])),
         ):
             for imported_name in updated_node.names:
                 if m.matches(imported_name, m.ImportAlias(name=m.Name("models"))):
@@ -102,7 +102,9 @@ class ModelsPermalinkTransformer(ContextAwareTransformer):
             for decorator in updated_node.decorators:
                 if m.matches(decorator, self.decorator_matcher):
                     AddImportsVisitor.add_needed_import(
-                        context=self.context, module="django.urls", obj="reverse",
+                        context=self.context,
+                        module="django.urls",
+                        obj="reverse",
                     )
                     updated_decorators = list(updated_node.decorators)
                     updated_decorators.remove(decorator)
@@ -139,7 +141,8 @@ def is_foreign_key(node: Call) -> bool:
 
 def is_one_to_one_field(node: Call) -> bool:
     return m.matches(
-        node, m.Call(func=m.Attribute(attr=m.Name(value="OneToOneField"))),
+        node,
+        m.Call(func=m.Attribute(attr=m.Name(value="OneToOneField"))),
     )
 
 
@@ -155,7 +158,9 @@ def has_on_delete(node: Call) -> bool:
     return len(node.args) >= 2 and node.args[1].keyword is None
 
 
-class OnDeleteTransformer(ContextAwareTransformer):
+class OnDeleteTransformer(BaseDjCodemodTransformer):
+    """Add the `on_delete=CASCADE` to `ForeignKey` and `OneToOneField`."""
+
     deprecated_in = DJANGO_1_9
     removed_in = DJANGO_2_0
     ctx_key_prefix = "OnDeleteTransformer"
@@ -165,7 +170,9 @@ class OnDeleteTransformer(ContextAwareTransformer):
             is_one_to_one_field(original_node) or is_foreign_key(original_node)
         ) and not has_on_delete(original_node):
             AddImportsVisitor.add_needed_import(
-                context=self.context, module="django.db", obj="models",
+                context=self.context,
+                module="django.db",
+                obj="models",
             )
             updated_args = (
                 *updated_node.args,
