@@ -221,7 +221,9 @@ def test_deprecated_in_mapping():
             "URLResolversTransformer",
         ],
         (1, 9): [
+            "AssignmentTagTransformer",
             "OnDeleteTransformer",
+            "SignalDisconnectWeakTransformer",
         ],
     }
 
@@ -265,7 +267,9 @@ def test_removed_in_mapping():
             "ModelsPermalinkTransformer",
         ],
         (2, 0): [
+            "AssignmentTagTransformer",
             "OnDeleteTransformer",
+            "SignalDisconnectWeakTransformer",
             "URLResolversTransformer",
         ],
     }
